@@ -1,6 +1,8 @@
 package resources
 
 import (
+	"time"
+
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/elb"
 	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
@@ -8,7 +10,7 @@ import (
 
 type ELBLoadBalancer struct {
 	svc  *elb.ELB
-	name *string
+	elb  *elb.LoadBalancerDescription
 	tags []*elb.Tag
 }
 
@@ -19,12 +21,14 @@ func init() {
 func ListELBLoadBalancers(sess *session.Session) ([]Resource, error) {
 	resources := make([]Resource, 0)
 	elbNames := make([]*string, 0)
+	elbNameToRsc := make(map[string]*elb.LoadBalancerDescription)
 	svc := elb.New(sess)
 
 	err := svc.DescribeLoadBalancersPages(nil,
 		func(page *elb.DescribeLoadBalancersOutput, lastPage bool) bool {
 			for _, desc := range page.LoadBalancerDescriptions {
 				elbNames = append(elbNames, desc.LoadBalancerName)
+				elbNameToRsc[*desc.LoadBalancerName] = desc
 			}
 			return !lastPage
 		})
@@ -46,9 +50,10 @@ func ListELBLoadBalancers(sess *session.Session) ([]Resource, error) {
 			return nil, err
 		}
 		for _, elbTagInfo := range tagResp.TagDescriptions {
+			elb := elbNameToRsc[*elbTagInfo.LoadBalancerName]
 			resources = append(resources, &ELBLoadBalancer{
 				svc:  svc,
-				name: elbTagInfo.LoadBalancerName,
+				elb:  elb,
 				tags: elbTagInfo.Tags,
 			})
 		}
@@ -62,7 +67,7 @@ func ListELBLoadBalancers(sess *session.Session) ([]Resource, error) {
 
 func (e *ELBLoadBalancer) Remove() error {
 	params := &elb.DeleteLoadBalancerInput{
-		LoadBalancerName: e.name,
+		LoadBalancerName: e.elb.LoadBalancerName,
 	}
 
 	_, err := e.svc.DeleteLoadBalancer(params)
@@ -74,13 +79,16 @@ func (e *ELBLoadBalancer) Remove() error {
 }
 
 func (e *ELBLoadBalancer) Properties() types.Properties {
-	properties := types.NewProperties()
+	properties := types.NewProperties().
+		Set("CreatedTime", e.elb.CreatedTime.Format(time.RFC3339))
+
 	for _, tagValue := range e.tags {
 		properties.SetTag(tagValue.Key, tagValue.Value)
 	}
+
 	return properties
 }
 
 func (e *ELBLoadBalancer) String() string {
-	return *e.name
+	return *e.elb.LoadBalancerName
 }
